#
# spec file for package luajit2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define abi_ver 5.1
%define so_ver 2
%define lib_ver 5_1-%{so_ver}
%define major 2.1
%define minor 20241113
%define upstream 1731486438
Name:           luajit2
Version:        %{major}.%{minor}
Release:        1.1
Summary:        OpenResty's maintained branch of LuaJIT
License:        MIT
URL:            https://github.com/openresty/%{name}
Source0:        https://github.com/openresty/%{name}/archive/refs/tags/v%{major}-%{minor}.tar.gz#/%{name}-%{major}-%{minor}.tar.gz
Source1:        baselibs.conf
Patch0:         %{name}-name.patch
BuildRequires:  pkgconfig
Requires:       lib%{name}-%{lib_ver} = %{version}

%description
This is the official OpenResty branch of LuaJIT. It is not to be considered a fork,
since we still regularly synchronize changes from the upstream LuaJIT project.

%package -n lib%{name}-%{lib_ver}
Summary:        Library for LuaJIT2 compiler

%description -n lib%{name}-%{lib_ver}
Libraries to use LuaJIT2 compiler.

%package devel
Summary:        Devel files for %{name}
Requires:       %{name} = %{version}
Requires:       lib%{name}-%{lib_ver} = %{version}

%description devel
Devel files for %{name} package.

%prep
%autosetup -p1 -n %{name}-%{major}-%{minor}

%build
%make_build %{?_make_output_sync} \
	Q= \
	DYNAMIC_CC="cc -fPIC" \
	LDCONFIG="true" \
	TARGET_AR="ar rcus" \
	TARGET_STRIP=: \
	PREFIX=%{_prefix} \
	MULTILIB=%{_lib} \
	CFLAGS="%{optflags}"

%install
%make_install \
	DYNAMIC_CC="cc -fPIC" \
	LDCONFIG="true" \
	TARGET_AR="ar rcus" \
	TARGET_STRIP=: \
	PREFIX=%{_prefix} \
	MULTILIB=%{_lib}

%post -n lib%{name}-%{lib_ver} -p /sbin/ldconfig
%postun -n lib%{name}-%{lib_ver} -p /sbin/ldconfig

%files
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_datadir}/%{name}-%{major}

%files -n lib%{name}-%{lib_ver}
%{_libdir}/lib%{name}-%{abi_ver}.so.%{so_ver}
%{_libdir}/lib%{name}-%{abi_ver}.so.%{major}.%{upstream}

%files devel
%{_includedir}/%{name}-%{major}
%{_libdir}/lib%{name}-%{abi_ver}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Sat Nov 23 2024 Илья Индиго <ilya@ilya.top>
- Updated to 2.1.20241113 (2.1.1731486438).
  * Upstream doesn't provide a ChangeLog.
* Thu Nov  7 2024 Илья Индиго <ilya@ilya.top>
- Updated to 2.1.20241104 (2.1.1728714540).
  * FFI: Added missing coercion when recording 64-bit bit.*().
  * ARM64: Used ldr literal to load FP constants.
* Wed Aug 28 2024 Илья Индиго <ilya@ilya.top>
- Updated to 2.1.20240815 (2.1.1723681758).
  * Changed file luajit2-name.patch.
  * Added ppc64le support.
* Fri May 10 2024 Илья Индиго <ilya@ilya.top>
- Changed file luajit2-name.patch and fixed package.path for modules.
* Fri May  3 2024 Илья Индиго <ilya@ilya.top>
- Removed %%check (tests don't run, and it's not known how to run them).
* Wed May  1 2024 Илья Индиго <ilya@ilya.top>
- Updated to 2.1.20240314 (2.1.1710398010).
- Refreshed spec-file via spec-cleaner and manual optimizations.
- Added file luajit2-name.patch.
- Renamed package to luajit2.
* Thu Jan 26 2023 Michal Suchanek <msuchanek@suse.de>
- Opencode %%make_build to prevent build failure when not defined.
* Wed Jan 25 2023 Matej Cepl <mcepl@suse.com>
- Rewrite moonjit package to build openresty from
  https://github.com/openresty/luajit2.
* Mon Jul 12 2021 Matej Cepl <mcepl@suse.com>
- Rewrite the packaging to acommodate a possibility of two LuaJIT
  implementations in the distribution.
* Sat Jul  3 2021 Matej Cepl <mcepl@suse.com>
- Fix Provides ... we don't provide an equvalent of 2.2.0 LuaJIT
  (which doesn't exsts).
* Mon Mar 30 2020 Matej Cepl <mcepl@suse.com>
- Add moonjit105-string_gsub.patch to fix gsub method, which breaks
  other packages (namely neovim).
* Thu Mar 12 2020 Tomáš Chvátal <tchvatal@suse.com>
- No need to namespace luajit with update-alternatives, we really
  want just one version of it to be provided to keep things
  simple
* Thu Mar 12 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.2.0:
  * The v2.2 release of moonjit brings many new features that bring the
    project closer to its aim of unifying LuaJIT forks and compatibility
    with Lua.
- Do not suffix the version anymore as we support all lua variants,
  removes the patch:
  * luajit-lua-versioned.patch
* Wed Dec 18 2019 Michel Normand <normand@linux.vnet.ibm.com>
- Ignore make check error for PowerPC until upstream solved issue
  https://github.com/moonjit/moonjit/issues/40
- do the same for %%arm rather than to disable all %%check.
* Mon Dec 16 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable %%check on %%arm until the following issue is fixed:
  https://github.com/moonjit/moonjit/issues/9
* Thu Dec 12 2019 Andreas Schwab <schwab@suse.de>
- Use %%_lib
* Mon Dec  9 2019 Tomáš Chvátal <tchvatal@suse.com>
- Obsolete/provide lua51-luajit as it was the old luajit name
* Fri Dec  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fork of luajit with more active upstream
- Version 2.1.2 building on top of 2.1.0-beta3 with following goodies:
  * fix for CVE-2019-19391
  * Support for ppc64 ppc64le s390 s390x
- Still carry the patch luajit-lua-versioned.patch to mark it as
  compatible with lua 5.1, future 2.2 release should contain
  support for 5.2 and 5.3 release of LUA
